package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.vehicle.api.dto.OmsOrderOperateHistoryDTO;
import com.chelvc.cloud.vehicle.api.service.OmsOrderOperateHistoryService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.common.model.Paging;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;
import javax.validation.Valid;

/**
 * 订单通知接口
 *
 * @author igl
 * @Date 2023/12/13
 **/
@Validated
@RestController
@ResponseWrapping
public class InformController {

    @DubboReference
    private OmsOrderOperateHistoryService omsOrderOperateHistoryService;


    /**
     * 获取用户的订单列表
     *
     * @param paging 分页信息
     * @return 用户的订单列表
     */
    @GetMapping("/order/inform")
    public Pagination<OmsOrderOperateHistoryDTO> listUserOrderInform(@Valid Paging paging) {
        return omsOrderOperateHistoryService.selectOmsOrderOperateHistoryListByUserId(SessionContextHolder.getId(), paging);
    }

    /**
     * 将新订单通知标识更改
     *
     */
    @PutMapping("/order/inform/flag")
    public void changeUserOrderInformFlag() {
        omsOrderOperateHistoryService.changeUserOrderInformFlag(SessionContextHolder.getId());
    }
}
